using System;
using Sce.PlayStation.Core;
using Sce.PlayStation.Core.Graphics;
using Sce.PlayStation.Core.Audio;
using Sce.PlayStation.HighLevel.GameEngine2D;
using Sce.PlayStation.HighLevel.GameEngine2D.Base;
using Sce.PlayStation.Core.Input;

namespace StreetDreams
{
	public class MainGameScene : Scene
	{
		private TextureInfo mainGameSceneBackgroundImageTextureInfo;
		private Texture2D mainGameSceneBackgroundImageTexture;
		private Bgm backgroundSong;
		private BgmPlayer backgroundSongPlayer;
		private SpriteUV mainGameSceneBackgroundSprite;
		private Boolean goToNextScene;
		private Boolean fadingOut;
		private Car player;
		private Goal goal;
		
		private const string backgroundImagePath = "Application/assets/images/MainGameSceneBackground.png";

		
		public MainGameScene ()
		{
			this.Camera.SetViewFromViewport();
			this.setUpBackground();
			player = new Car(this.Camera2D.Center.X-300.0f, this.Camera2D.Center.Y-250.0f);
			this.AddChild(player);
			goal = new Goal(100000.0f, this.Camera2D.Center.Y-150.0f);
			this.AddChild (goal);
			Scheduler.Instance.ScheduleUpdateForTarget(player,0,false);
			Scheduler.Instance.ScheduleUpdateForTarget(this,0,false);
			Touch.GetData(0).Clear();
		}
		
		public override void Update(float dt)
		{
			base.Update(dt);
			this.checkControls();
			this.checkWinCondition();
			this.updateCamera();
		}
		
		private void checkWinCondition()
		{
			if(player.Position.X >= goal.x)
			{
				Director.Instance.ReplaceScene(new MainMenuScene());
			}
		}
		
		private void updateCamera()
		{
			this.Camera2D.Center = new Vector2(this.Camera2D.Center.X+player.speed,
					                           this.Camera2D.Center.Y);
		}
		
		private void setUpBackground()
		{
			this.mainGameSceneBackgroundImageTexture = new Texture2D(backgroundImagePath,false);
			this.mainGameSceneBackgroundImageTextureInfo = new TextureInfo(this.mainGameSceneBackgroundImageTexture);
			float pivotCenter = 0.5f;
			for(int i = 0; i < 500; i++)
			{
				this.mainGameSceneBackgroundSprite = new SpriteUV(this.mainGameSceneBackgroundImageTextureInfo);
				this.mainGameSceneBackgroundSprite.Scale = this.mainGameSceneBackgroundImageTextureInfo.TextureSizef/2;
				this.mainGameSceneBackgroundSprite.Pivot = new Vector2(pivotCenter,pivotCenter);
				this.mainGameSceneBackgroundSprite.Position = new Vector2(Director.Instance.GL.Context.GetViewport().Width/2 + (i*this.mainGameSceneBackgroundImageTextureInfo.TextureSizef.X/2),
			                                              			      Director.Instance.GL.Context.GetViewport().Height/2);	
				this.AddChild(mainGameSceneBackgroundSprite);
			}
		}
		
		private void checkControls()
		{
			var touches = Touch.GetData(0).ToArray();
		    if(Input2.GamePad0.Cross.Down)
			{
				player.accelerate();
			}
			else
			{
				player.decelerate();
			}
		}
	}
}

